[![Test](https://github.com/Quasars/pySNOM/actions/workflows/test.yml/badge.svg)](https://github.com/Quasars/pySNOM/actions/workflows/test.yml)
[![Release](https://github.com/Quasars/pySNOM/actions/workflows/release.yml/badge.svg)](https://github.com/Quasars/pySNOM/actions/workflows/release.yml)
# pySNOM
Scanning Near-field Optical Microscopy (SNOM) analysis tools
